import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { AddDeliveryRegionOptions, AddDeliveryRegionResponse, CreateShippoConfigurationOptions, RemoveDeliveryRegionIdentifiers, RemoveDeliveryRegionOptions, RemoveDeliveryRegionResponse, ShippoConfiguration, ShippoConfigurationCreatedEnvelope, ShippoConfigurationDeletedEnvelope, ShippoConfigurationUpdatedEnvelope, ShippoConfigurationsQueryBuilder, UpdateExtendedFieldsOptions, UpdateExtendedFieldsResponse, UpdateShippoConfiguration } from './ecom-v1-shippo-configuration-shippo-configurations.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function createShippoConfiguration(httpClient: HttpClient): CreateShippoConfigurationSignature;
interface CreateShippoConfigurationSignature {
    /**
     * Creates a ShippoConfiguration.
     * @param - ShippoConfiguration to be created.
     * @returns The created ShippoConfiguration.
     */
    (shippoConfiguration: ShippoConfiguration, options?: CreateShippoConfigurationOptions | undefined): Promise<ShippoConfiguration>;
}
export declare function getShippoConfiguration(httpClient: HttpClient): GetShippoConfigurationSignature;
interface GetShippoConfigurationSignature {
    /**
     * Retrieves a ShippoConfiguration.
     * @param - ID of the ShippoConfiguration to retrieve.
     * @returns The requested ShippoConfiguration.
     */
    (shippoConfigurationId: string): Promise<ShippoConfiguration>;
}
export declare function updateShippoConfiguration(httpClient: HttpClient): UpdateShippoConfigurationSignature;
interface UpdateShippoConfigurationSignature {
    /**
     * Updates a ShippoConfiguration.
     * @param - ShippoConfiguration ID.
     * @returns Updated ShippoConfiguration.
     */
    (_id: string, shippoConfiguration: UpdateShippoConfiguration): Promise<ShippoConfiguration>;
}
export declare function deleteShippoConfiguration(httpClient: HttpClient): DeleteShippoConfigurationSignature;
interface DeleteShippoConfigurationSignature {
    /**
     * Deletes a ShippoConfiguration.
     * @param - ID of the ShippoConfiguration to delete.
     */
    (shippoConfigurationId: string): Promise<void>;
}
export declare function queryShippoConfigurations(httpClient: HttpClient): QueryShippoConfigurationsSignature;
interface QueryShippoConfigurationsSignature {
    /**
     * Retrieves a list of ShippoConfigurations, given the provided [paging, filtering, and sorting][1].
     *
     * Up to 1,000 ShippoConfigurations can be returned per request.
     *
     * To learn how to query ShippoConfigurations, see [API Query Language][2].
     *
     * [1]: https://dev.wix.com/api/rest/getting-started/sorting-and-paging
     * [2]: https://dev.wix.com/api/rest/getting-started/api-query-language
     */
    (): ShippoConfigurationsQueryBuilder;
}
export declare function updateExtendedFields(httpClient: HttpClient): UpdateExtendedFieldsSignature;
interface UpdateExtendedFieldsSignature {
    /**
     * Updates extended fields of a ShippoConfiguration without incrementing revision
     * @param - ID of the entity to update.
     * @param - Identifier for the app whose extended fields are being updated.
     */
    (_id: string, namespace: string, options: UpdateExtendedFieldsOptions): Promise<UpdateExtendedFieldsResponse>;
}
export declare function addDeliveryRegion(httpClient: HttpClient): AddDeliveryRegionSignature;
interface AddDeliveryRegionSignature {
    /**
     * Adds a delivery region to a Shippo configuration.
     * @param - ID of the ShippoConfiguration to add the delivery region to.
     * @param - ID of the delivery region to add.
     */
    (shippoConfigurationId: string, deliveryRegionId: string, options?: AddDeliveryRegionOptions | undefined): Promise<AddDeliveryRegionResponse>;
}
export declare function removeDeliveryRegion(httpClient: HttpClient): RemoveDeliveryRegionSignature;
interface RemoveDeliveryRegionSignature {
    /**
     * Removes a delivery region from a Shippo configuration.
     * When passing the ID of the only existing delivery region, removing it will delete the Shippo configuration.
     */
    (identifiers: RemoveDeliveryRegionIdentifiers, options?: RemoveDeliveryRegionOptions | undefined): Promise<RemoveDeliveryRegionResponse>;
}
export declare const onShippoConfigurationCreated: EventDefinition<ShippoConfigurationCreatedEnvelope, "wix.ecom.v1.shippo_configuration_created">;
export declare const onShippoConfigurationDeleted: EventDefinition<ShippoConfigurationDeletedEnvelope, "wix.ecom.v1.shippo_configuration_deleted">;
export declare const onShippoConfigurationUpdated: EventDefinition<ShippoConfigurationUpdatedEnvelope, "wix.ecom.v1.shippo_configuration_updated">;
export { ActionEvent, AddDeliveryRegionOptions, AddDeliveryRegionRequest, AddDeliveryRegionResponse, Address, AddressLocation, BaseEventMetadata, CalculationType, CreateShippoConfigurationOptions, CreateShippoConfigurationRequest, CreateShippoConfigurationResponse, CursorPaging, CursorPagingMetadata, CursorQuery, CursorQueryPagingMethodOneOf, Cursors, DeleteShippoConfigurationRequest, DeleteShippoConfigurationResponse, DomainEvent, DomainEventBodyOneOf, DomesticService, DomesticServiceSettings, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, ExtendedFields, GetShippoConfigurationRequest, GetShippoConfigurationResponse, HandlingFee, IdentificationData, IdentificationDataIdOneOf, InternationalService, InternationalServiceSettings, MessageEnvelope, PackageDetails, PackageDimensions, PackageType, QueryShippoConfigurationsRequest, QueryShippoConfigurationsResponse, RemoveDeliveryRegionIdentifiers, RemoveDeliveryRegionOptions, RemoveDeliveryRegionRequest, RemoveDeliveryRegionResponse, RestoreInfo, ServiceSettings, ShippoConfiguration, ShippoConfigurationCreatedEnvelope, ShippoConfigurationDeletedEnvelope, ShippoConfigurationUpdatedEnvelope, ShippoConfigurationsQueryBuilder, ShippoConfigurationsQueryResult, SortOrder, Sorting, StreetAddress, UpdateExtendedFieldsOptions, UpdateExtendedFieldsRequest, UpdateExtendedFieldsResponse, UpdateShippoConfiguration, UpdateShippoConfigurationRequest, UpdateShippoConfigurationResponse, WebhookIdentityType, } from './ecom-v1-shippo-configuration-shippo-configurations.universal.js';
